@@ -11,9 +11,22 @@ from TwitterAPI import TwitterAPI, TwitterPager
 
 import networkx as nx
 
-from utils import *
+def create_dir(dir_name):
+    if not os.path.exists(dir_name):
+        os.makedirs(dir_name)
 
 
+def is_folder_exists(folder_name):
+    return os.path.exists(folder_name)
+
+
+def encode_query(query):
+    '''
+    To preserve the original query, the query is
+    url-encoded with no safe ("/") characters.
+    '''
+    return (urllib.parse.quote(query.strip(), safe=''))
+
 def create_api(config):
     # Create a Twitter API object
     api = TwitterAPI(config['app_key'],
